colour.colorimetry.dataset.illuminants Package — Colour 0.3.0 documentation

# colour.colorimetry.dataset.illuminants Package

## Sub-Modules

- colour.colorimetry.dataset.illuminants.chromaticity_coordinates Module
  - Illuminants Chromaticity Coordinates
- colour.colorimetry.dataset.illuminants.d_illuminants_s_spds Module
  - CIE Standard Illuminant D Series \(S_n(\lambda)\) Spectral Power Distributions
- colour.colorimetry.dataset.illuminants.spds Module
  - Illuminants Relative Spectral Power Distributions

## Module Contents